import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'maintCode',
    label: '保养工单'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_MAINT_TYPE)
    },
    fieldName: 'maintType',
    label: '保养类型'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'maintDept',
    label: '保养部门'
  },
  {
    component: 'Select',
    componentProps: {
      allowClear: true,
      showSearch: true,
      getPopupContainer
    },
    fieldName: 'maintUser',
    label: '保养人'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.MAINT_TIME_RULE)
    },
    fieldName: 'maintRule',
    label: '计算规则'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.MAINT_ORDER_STATUS)
    },
    fieldName: 'status',
    label: '状态'
  }
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '保养工单',
    field: 'maintCode',
    minWidth: 200,
    fixed: 'left'
  },

  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.MAINT_ORDER_STATUS);
      }
    }
  },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 200,
  },
  {
    title: '资产编号',
    field: 'assetNo',
    minWidth: 160
  },
  {
    title: '保养项',
    field: 'maintName',
    minWidth: 160
  },
  {
    title: '保养类型',
    field: 'maintType',
    minWidth: 120,
    slots: {
      default: ({ row }) => {
        return renderDict(row.maintType, DictEnum.EIMS_MAINT_TYPE);
      }
    }
  },
  {
    title: '保养人',
    field: 'maintUserName',
    minWidth: 100
  },
  {
    title: '计划保养时间',
    field: 'planTime',
    minWidth: 160
  },
  {
    title: '保养开始时间',
    field: 'startTime',
    minWidth: 160
  },
  {
    title: '保养结束时间',
    field: 'endTime',
    minWidth: 160
  },
  {
    title: '验证人',
    field: 'verifyUserName',
    minWidth: 160
  },
  {
    title: '创建时间',
    field: 'createTime',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'planId',
  },
  {
    component: 'Input',
    fieldName: 'equId',
    label: '设备id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'maintCode',
    label: '保养单号'
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_MAINT_TYPE),
      optionType: 'button'
    },
    fieldName: 'maintType',
    defaultValue: '1',
    label: '保养类型'
  },
  /*
  {
    component: 'InputNumber',
    fieldName: 'maintCycle',
    label: '保养周期',
    formItemClass: 'col-span-1',
    componentProps: {
      min: 1
    }
  },
 {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.MAINT_CYCLE_UNIT)
    },
    fieldName: 'maintCycleUnit',
    formItemClass: 'col-span-1 w-[80px]',
    labelWidth: 0,
    label: ''
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.MAINT_TIME_RULE)
    },
    fieldName: 'maintRule',
    label: '保养规则 '
  },*/
  {
    component: 'Input',
    fieldName: 'maintUser',
    label: '保养人id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'maintUserName',
    label: '保养人'
  },
  {
    component: 'Input',
    fieldName: 'maintDept',
    label: '部门id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.MAINT_ORDER_STATUS),
      optionType: 'button'
    },
    fieldName: 'status',
    defaultValue: '0',
    label: '状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'planTime',
    label: '计划保养日期'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'startTime',
    label: '开始时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD HH:mm:ss',
      showTime: true,
      valueFormat: 'YYYY-MM-DD HH:mm:ss',
      getPopupContainer
    },
    fieldName: 'endTime',
    label: '结束时间'
  },
  {
    component: 'Input',
    fieldName: 'verifyUser',
    label: '验证人id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'verifyUserName',
    label: '验证人'
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
